tonalanalysistools.Mode
=======================

.. abjad-lineage:: abjad.tools.tonalanalysistools.Mode.Mode

.. autoclass:: abjad.tools.tonalanalysistools.Mode.Mode

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.Mode.Mode.mode_name
      ~abjad.tools.tonalanalysistools.Mode.Mode.named_interval_segment
      ~abjad.tools.tonalanalysistools.Mode.Mode.__eq__
      ~abjad.tools.tonalanalysistools.Mode.Mode.__format__
      ~abjad.tools.tonalanalysistools.Mode.Mode.__hash__
      ~abjad.tools.tonalanalysistools.Mode.Mode.__len__
      ~abjad.tools.tonalanalysistools.Mode.Mode.__ne__
      ~abjad.tools.tonalanalysistools.Mode.Mode.__repr__
      ~abjad.tools.tonalanalysistools.Mode.Mode.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.Mode.Mode.mode_name
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Mode.Mode.named_interval_segment
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.Mode.Mode.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Mode.Mode.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Mode.Mode.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Mode.Mode.__len__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Mode.Mode.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Mode.Mode.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Mode.Mode.__str__
   :noindex:
